﻿------------------------------------------------------------------------------------
-- NiceColorize by Mr.Dio (Demorto#2660) Version 7.2.5.0 (19:35 07.08.2017)
------------------------------------------------------------------------------------
--
-- Frames Colorize Module
--
------------------------------------------------------------------------------------
-- NiceColorize
------------------------------------------------------------------------------------

function FramesColorizeModule_Init(Cfg)

	local ClassColor = RAID_CLASS_COLORS[select(2, UnitClass("player"))]

	if Cfg.Class then
		Cfg.TopColor.Red, Cfg.TopColor.Green, Cfg.TopColor.Blue = (ClassColor.r * 1.2), (ClassColor.g * 1.2), (ClassColor.b * 1.2)
	end

	function Colorize(frame, R, G, B, Gradient)
	if frame:GetObjectType() == "Texture" then
		if Gradient then
			frame:SetGradientAlpha("VERTICAL", Cfg.BottomColor.Red, Cfg.BottomColor.Green, Cfg.BottomColor.Blue, Cfg.BottomColor.Alpha, R, G, B, Cfg.TopColor.Alpha)
		else
			frame:SetVertexColor(R, G, B, Cfg.TopColor.Alpha)
		end
	end
	end

	function DeColorize(frame)
		if frame:GetObjectType() == "Texture" then
			frame:SetVertexColor(1, 1, 1, 1)
		end
	end

	function RaidColorize()
		for g = 1, NUM_RAID_GROUPS do
			local group = _G["CompactRaidGroup"..g.."BorderFrame"]
			if group then
				for _, region in pairs({group:GetRegions()}) do
					if region:IsObjectType("Texture") then
						if Cfg.ModuleEnable then
							Colorize(region, R, G, B, false)
						else
							DeColorize(region)
						end
					end
				end
			end
			for m = 1, 5 do
				local frame = _G["CompactRaidGroup"..g.."Member"..m]
				if frame then
					for _, region in pairs({frame:GetRegions()}) do
						if region:GetName():find("Border") then
							if Cfg.ModuleEnable then
								Colorize(region, R, G, B, false)
							else
								DeColorize(region)
							end
						end
					end
				end
			end
			for r = 1, MAX_RAID_MEMBERS do
				local frame = _G["CompactRaidFrame"..r]
				if frame then
					for _, region in pairs({frame:GetRegions()}) do
						if region:GetName():find("Border") then
							if Cfg.ModuleEnable then
								Colorize(region, R, G, B, false)
							else
								DeColorize(region)
							end
						end
					end
				end
			end
		end
		for _, region in pairs({CompactRaidFrameContainerBorderFrame:GetRegions()}) do
			if region:IsObjectType("Texture") then
				if Cfg.ModuleEnable then
					Colorize(region, R, G, B, false)
				else
					DeColorize(region)
				end
			end
		end
	end

	hooksecurefunc("CompactRaidFrameManager_UpdateGroupFilterButton", function(self)
		RaidColorize()
	end)

	local ArenaFrameColorize = CreateFrame("Frame")
	local _, instanceType = IsInInstance()
	ArenaFrameColorize:RegisterEvent("ADDON_LOADED")
	ArenaFrameColorize:RegisterEvent("PLAYER_ENTERING_WORLD")
	ArenaFrameColorize:RegisterEvent("ARENA_PREP_OPPONENT_SPECIALIZATIONS")
	ArenaFrameColorize:SetScript("OnEvent", function(self, event, addon)
		if addon == "Blizzard_ArenaUI" and not (IsAddOnLoaded("Shadowed Unit Frames")) then
			for i,v in pairs({
	 			ArenaEnemyFrame1Texture,
				ArenaEnemyFrame2Texture,
				ArenaEnemyFrame3Texture,
				ArenaEnemyFrame4Texture,
				ArenaEnemyFrame5Texture,
				ArenaEnemyFrame1SpecBorder,
				ArenaEnemyFrame2SpecBorder,
				ArenaEnemyFrame3SpecBorder,
				ArenaEnemyFrame4SpecBorder,
				ArenaEnemyFrame5SpecBorder,
				ArenaEnemyFrame1PetFrameTexture,
				ArenaEnemyFrame2PetFrameTexture,
				ArenaEnemyFrame3PetFrameTexture,
				ArenaEnemyFrame4PetFrameTexture,
				ArenaEnemyFrame5PetFrameTexture,
			}) do
				if Cfg.ModuleEnable then
					Colorize(v, R, G, B, Cfg.Gradient)
				else
					DeColorize(v)
				end
			end
		elseif event == "ARENA_PREP_OPPONENT_SPECIALIZATIONS" or (event == "PLAYER_ENTERING_WORLD" and instanceType == "arena") then
			for i,v in pairs({
				ArenaPrepFrame1Texture,
				ArenaPrepFrame2Texture,
				ArenaPrepFrame3Texture,
				ArenaPrepFrame4Texture,
				ArenaPrepFrame5Texture,
				ArenaPrepFrame1SpecBorder,
				ArenaPrepFrame2SpecBorder,
				ArenaPrepFrame3SpecBorder,
				ArenaPrepFrame4SpecBorder,
				ArenaPrepFrame5SpecBorder,
			}) do
				if Cfg.ModuleEnable then
					Colorize(v, R, G, B, Cfg.Gradient)
				else
					DeColorize(v)
				end
			end
		end
	end)

	return true

end

function FramesColorizeModule_Update(Cfg)

	local ClassColor = RAID_CLASS_COLORS[select(2, UnitClass("player"))]

	if Cfg.Class then
		R, G, B = (ClassColor.r * 1.2), (ClassColor.g * 1.2), (ClassColor.b * 1.2)
	else
		R, G, B = Cfg.TopColor.Red, Cfg.TopColor.Green, Cfg.TopColor.Blue
	end

	if not (IsAddOnLoaded("SexyMap")) then
		for i,v in pairs({
			MinimapBorder,
			MiniMapMailBorder,
			MiniMapTrackingButtonBorder,
			MiniMapBattlefieldBorder,
			MinimapBorderTop,
			QueueStatusMinimapButtonBorder,
			select(1, TimeManagerClockButton:GetRegions()),
			select(2, GarrisonLandingPageMinimapButton:GetRegions()),
			QueueStatusMinimapButton:GetRegions(),
			MinimapBackdrop,
			MinimapZoneTextButton,
			MiniMapInstanceDifficulty:GetRegions(),
			MinimapZoomIn:GetRegions(),
			select(3, MinimapZoomIn:GetRegions()),
			MinimapZoomOut:GetRegions(),
			select(3, MinimapZoomOut:GetRegions()),
			MiniMapWorldMapButton:GetRegions(),
			select(6, GameTimeFrame:GetRegions()),
		}) do
			if Cfg.ModuleEnable then
				Colorize(v, R, G, B, Cfg.Gradient)
			else
				DeColorize(v)
			end
		end
		select(2, TimeManagerClockButton:GetRegions()):SetVertexColor(1,1,1)
	end

--[[
		if Cfg.ModuleEnable then
			Colorize(v, R, G, B, Cfg.Gradient)
		else
			DeColorize(v)
		end
]]--

	if CompactRaidGroup1 then
		RaidColorize()
	end
	if CompactRaidFrame1 then
		RaidColorize()
	end

	if not (IsAddOnLoaded("Shadowed Unit Frames") or IsAddOnLoaded("PitBull Unit Frames 4.0") or IsAddOnLoaded("X-Perl UnitFrames")) then
		if IsAddOnLoaded("Blizzard_ArenaUI") then
			for i,v in pairs({
				ArenaEnemyFrame1Texture,
				ArenaEnemyFrame2Texture,
				ArenaEnemyFrame3Texture,
				ArenaEnemyFrame4Texture,
				ArenaEnemyFrame5Texture,
				ArenaEnemyFrame1SpecBorder,
				ArenaEnemyFrame2SpecBorder,
				ArenaEnemyFrame3SpecBorder,
				ArenaEnemyFrame4SpecBorder,
				ArenaEnemyFrame5SpecBorder,
				ArenaEnemyFrame1PetFrameTexture,
				ArenaEnemyFrame2PetFrameTexture,
				ArenaEnemyFrame3PetFrameTexture,
				ArenaEnemyFrame4PetFrameTexture,
				ArenaEnemyFrame5PetFrameTexture,
			}) do
				if Cfg.ModuleEnable then
					Colorize(v, R, G, B, Cfg.Gradient)
				else
					DeColorize(v)
				end
			end
		end

		for i,v in pairs({
			PlayerFrameTexture,
			TargetFrameTextureFrameTexture,
			PlayerFrameAlternateManaBarBorder,
			PlayerFrameAlternateManaBarLeftBorder,
			PlayerFrameAlternateManaBarRightBorder,
			PaladinPowerBarFrameBG,
			PaladinPowerBarFrameBankBG,
			ComboPointPlayerFrame.Background,
			ComboPointPlayerFrame.Combo1.PointOff,
			ComboPointPlayerFrame.Combo2.PointOff,
			ComboPointPlayerFrame.Combo3.PointOff,
			ComboPointPlayerFrame.Combo4.PointOff,
			ComboPointPlayerFrame.Combo5.PointOff,
			ComboPointPlayerFrame.Combo6.PointOff,
			AlternatePowerBarBorder,
			AlternatePowerBarLeftBorder,
			AlternatePowerBarRightBorder,
			PetFrameTexture,
			PartyMemberFrame1Texture,
			PartyMemberFrame2Texture,
			PartyMemberFrame3Texture,
			PartyMemberFrame4Texture,
			PartyMemberFrame1PetFrameTexture,
			PartyMemberFrame2PetFrameTexture,
			PartyMemberFrame3PetFrameTexture,
			PartyMemberFrame4PetFrameTexture,
			FocusFrameTextureFrameTexture,
			TargetFrameToTTextureFrameTexture,
			FocusFrameToTTextureFrameTexture,
			Boss1TargetFrameTextureFrameTexture,
			Boss2TargetFrameTextureFrameTexture,
			Boss3TargetFrameTextureFrameTexture,
			Boss4TargetFrameTextureFrameTexture,
			Boss5TargetFrameTextureFrameTexture,
			Boss1TargetFrameSpellBar.Border,
			Boss2TargetFrameSpellBar.Border,
			Boss3TargetFrameSpellBar.Border,
			Boss4TargetFrameSpellBar.Border,
			Boss5TargetFrameSpellBar.Border,
			CastingBarFrame.Border,
			FocusFrameSpellBar.Border,
			TargetFrameSpellBar.Border,

		}) do
			if Cfg.ModuleEnable then
				Colorize(v, R, G, B, Cfg.Gradient)
			else
				DeColorize(v)
			end
		end

		for _, region in pairs({StopwatchFrame:GetRegions()}) do
			if Cfg.ModuleEnable then
					Colorize(region, R, G, B, Cfg.Gradient)
				else
					DeColorize(region)
				end
			end

			for _, region in pairs({CompactRaidFrameManager:GetRegions()}) do
				if region:IsObjectType("Texture") then
					if Cfg.ModuleEnable then
						Colorize(region, R, G, B, Cfg.Gradient)
					else
						DeColorize(region)
					end
				end
			end
			for _, region in pairs({CompactRaidFrameManagerContainerResizeFrame:GetRegions()}) do
				if region:GetName():find("Border") then
					if Cfg.ModuleEnable then
						Colorize(region, R, G, B, Cfg.Gradient)
					else
						DeColorize(region)
					end
				end
			end

			hooksecurefunc("GameTooltip_ShowCompareItem", function(self, anchorFrame)
				if self then
					local shoppingTooltip1, shoppingTooltip2 = unpack(self.shoppingTooltips)
					if Cfg.ModuleEnable then
						shoppingTooltip1:SetBackdropBorderColor(R, G, B)
						shoppingTooltip2:SetBackdropBorderColor(R, G, B)
					else
						shoppingTooltip1:SetBackdropBorderColor(1, 1, 1)
						shoppingTooltip2:SetBackdropBorderColor(1, 1, 1)
					end
				end
			end)

			if Cfg.ModuleEnable then
				TOOLTIP_DEFAULT_COLOR = { r = R, g = G, b = B }
				TOOLTIP_DEFAULT_BACKGROUND_COLOR = { r = R * 0.2, g = G * 0.2, b = B * 0.2}
			else
				TOOLTIP_DEFAULT_COLOR = { r = 1, g = 1, b = 1 }
				TOOLTIP_DEFAULT_BACKGROUND_COLOR = { r = 0.09, g = 0.09, b = 0.19 }
			end

 			for _, child in pairs({WarlockPowerFrame:GetChildren()}) do
				for _, region in pairs({child:GetRegions()}) do
 					if region:GetDrawLayer() == "BORDER" then
						if Cfg.ModuleEnable then
							Colorize(region, R, G, B, Cfg.Gradient)
						else
							DeColorize(region)
						end
 					end
				end
 			end



			for i,v in pairs({
				MainMenuXPBarTextureLeftCap,
				MainMenuXPBarTextureRightCap,
				MainMenuXPBarTextureMid,
			}) do
				if Cfg.ModuleEnable then
					Colorize(v, R, G, B, false)
				else
					DeColorize(v)
				end
			end

			for i,v in pairs({
				SlidingActionBarTexture0,
				SlidingActionBarTexture1,
				MainMenuBarTexture0,
				MainMenuBarTexture1,
				MainMenuBarTexture2,
				MainMenuBarTexture3,
				MainMenuMaxLevelBar0,
				MainMenuMaxLevelBar1,
				MainMenuMaxLevelBar2,
				MainMenuMaxLevelBar3,
				ReputationWatchBarTexture0,
				ReputationWatchBarTexture1,
				ReputationWatchBarTexture2,
				ReputationWatchBarTexture3,
				ReputationXPBarTexture0,
				ReputationXPBarTexture1,
				ReputationXPBarTexture2,
				ReputationXPBarTexture3,
				ReputationWatchBar.StatusBar.XPBarTexture0,
				ReputationWatchBar.StatusBar.XPBarTexture1,
				ReputationWatchBar.StatusBar.XPBarTexture2,
				ReputationWatchBar.StatusBar.XPBarTexture3,
				ReputationWatchBar.StatusBar.WatchBarTexture0,
				ReputationWatchBar.StatusBar.WatchBarTexture1,
				ReputationWatchBar.StatusBar.WatchBarTexture2,
				ReputationWatchBar.StatusBar.WatchBarTexture3,
				ArtifactWatchBar.StatusBar.XPBarTexture0,
				ArtifactWatchBar.StatusBar.XPBarTexture1,
				ArtifactWatchBar.StatusBar.XPBarTexture2,
				ArtifactWatchBar.StatusBar.XPBarTexture3,
				ArtifactWatchBar.StatusBar.WatchBarTexture0,
				ArtifactWatchBar.StatusBar.WatchBarTexture1,
				ArtifactWatchBar.StatusBar.WatchBarTexture2,
				ArtifactWatchBar.StatusBar.WatchBarTexture3,
				HonorWatchBar.StatusBar.XPBarTexture0,
				HonorWatchBar.StatusBar.XPBarTexture1,
				HonorWatchBar.StatusBar.XPBarTexture2,
				HonorWatchBar.StatusBar.XPBarTexture3,
				HonorWatchBar.StatusBar.WatchBarTexture0,
				HonorWatchBar.StatusBar.WatchBarTexture1,
				HonorWatchBar.StatusBar.WatchBarTexture2,
				HonorWatchBar.StatusBar.WatchBarTexture3,
				ActionBarUpButton:GetRegions(),
				ActionBarDownButton:GetRegions(),
			-- Micro menu
				select(2, CharacterMicroButton:GetRegions()),
				select(3, CharacterMicroButton:GetRegions()),
				select(2, SpellbookMicroButton:GetRegions()),
				select(2, TalentMicroButton:GetRegions()),
				select(2, AchievementMicroButton:GetRegions()),
				select(2, QuestLogMicroButton:GetRegions()),
				select(2, GuildMicroButton:GetRegions()),
				select(2, LFDMicroButton:GetRegions()),
				select(2, CollectionsMicroButton:GetRegions()),
				select(2, EJMicroButton:GetRegions()),
				select(2, StoreMicroButton:GetRegions()),
				select(4, MainMenuMicroButton:GetRegions()),
			-- Chat
				select(1, QuickJoinToastButton:GetRegions()),
				ChatFrameMenuButton:GetRegions(),
				ChatFrame1ButtonFrameUpButton:GetRegions(),
				ChatFrame1ButtonFrameDownButton:GetRegions(),
				select(2, ChatFrame1ButtonFrameBottomButton:GetRegions()),
				ChatFrame2ButtonFrameUpButton:GetRegions(),
				ChatFrame2ButtonFrameDownButton:GetRegions(),
				select(2, ChatFrame2ButtonFrameBottomButton:GetRegions()),
				ChatFrame1EditBox:GetRegions(),
			}) do
				if Cfg.ModuleEnable then
					Colorize(v, R, G, B, Cfg.Gradient)
				else
					DeColorize(v)
				end
			end

			for i = 1, 19 do
				if Cfg.ModuleEnable then
					Colorize(_G["MainMenuXPBarDiv"..i], R, G, B, false)
				else
					DeColorize(_G["MainMenuXPBarDiv"..i])
				end
			end

--			ArtifactWatchBar.Tick.Normal:SetVertexColor(0.4, 0.4, 0.4)
--			ExhaustionTick:SetAlpha(0)

			for i,v in pairs({
				StanceBarLeft,
				StanceBarMiddle,
				StanceBarRight,
			}) do
				if Cfg.ModuleEnable then
					Colorize(v, R, G, B, Cfg.Gradient)
				else
					DeColorize(v)
				end
			end

			if Cfg.ModuleEnable then
				if Cfg.Gradient then
					MainMenuBarLeftEndCap:SetGradientAlpha("HORIZONTAL", Cfg.BottomColor.Red, Cfg.BottomColor.Green, Cfg.BottomColor.Blue, Cfg.BottomColor.Alpha, R, G, B, Cfg.TopColor.Alpha)
					MainMenuBarRightEndCap:SetGradientAlpha("HORIZONTAL", R, G, B, Cfg.TopColor.Alpha, Cfg.BottomColor.Red, Cfg.BottomColor.Green, Cfg.BottomColor.Blue, Cfg.BottomColor.Alpha)
				else
					MainMenuBarLeftEndCap:SetVertexColor(R, G, B, Cfg.TopColor.Alpha)
					MainMenuBarRightEndCap:SetVertexColor(R, G, B, Cfg.TopColor.Alpha)
				end
			else
				DeColorize(MainMenuBarLeftEndCap)
				DeColorize(MainMenuBarRightEndCap)
			end

		end
end